HilbertEOF
==========

.. currentmodule:: xeofs.single

.. autoclass:: HilbertEOF
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HilbertEOF.__init__
      ~HilbertEOF.components
      ~HilbertEOF.components_amplitude
      ~HilbertEOF.components_phase
      ~HilbertEOF.compute
      ~HilbertEOF.deserialize
      ~HilbertEOF.explained_variance
      ~HilbertEOF.explained_variance_ratio
      ~HilbertEOF.fit
      ~HilbertEOF.fit_transform
      ~HilbertEOF.get_params
      ~HilbertEOF.get_serialization_attrs
      ~HilbertEOF.inverse_transform
      ~HilbertEOF.load
      ~HilbertEOF.save
      ~HilbertEOF.scores
      ~HilbertEOF.scores_amplitude
      ~HilbertEOF.scores_phase
      ~HilbertEOF.serialize
      ~HilbertEOF.singular_values
      ~HilbertEOF.transform
   
   

   
   
   